@@ -133,6 +133,10 @@ class SASconfig(object):
         # Get Config options. Fallback to empty dict.
         self.cfgopts = getattr(SAScfg, "SAS_config_options", {})
 
+        # See if we don't want to allow prompting in this environment
+        prompt = self.cfgopts.get('prompt', True)
+        self.prompt = kwargs.get('prompt', prompt)
+
         # In lock down mode, don't allow runtime overrides of option values from the config file.
         lock = self.cfgopts.get('lock_down', True)
 
@@ -159,7 +163,7 @@ class SASconfig(object):
                 "The SAS Config name specified was not found. Please enter the SAS Config you wish to use. Available Configs are: " +
                 str(configs) + " ")
             if cfgname is None:
-                raise KeyboardInterrupt
+                raise RuntimeError("No SAS Config name provided.") 
 
         self.name = cfgname
         cfg = getattr(SAScfg, cfgname)
@@ -328,24 +332,26 @@ class SASconfig(object):
         return SAScfg
 
     def _prompt(self, prompt, pw=False):
-        if self._kernel is None:
-            if not pw:
-                try:
-                    return input(prompt)
-                except KeyboardInterrupt:
-                    return None
-            else:
-                try:
-                    return getpass.getpass(prompt)
-                except KeyboardInterrupt:
-                    return None
+        if self.prompt:
+           if self._kernel is None:
+               if not pw:
+                   try:
+                       return input(prompt)
+                   except KeyboardInterrupt:
+                       return None
+               else:
+                   try:
+                       return getpass.getpass(prompt)
+                   except KeyboardInterrupt:
+                       return None
+           else:
+               try:
+                   return self._kernel._input_request(prompt, self._kernel._parent_ident, self._kernel._parent_header,
+                                                      password=pw)
+               except KeyboardInterrupt:
+                   return None
         else:
-            try:
-                return self._kernel._input_request(prompt, self._kernel._parent_ident, self._kernel._parent_header,
-                                                   password=pw)
-            except KeyboardInterrupt:
-                return None
-
+           return None 
 
 class SASsession():
     """
@@ -1541,12 +1547,19 @@ class SASsession():
     def symget(self, name: str, outtype=None):
         """
         :param name:    [required] name of the macro varable to get
-        :param outtype: [optional] desired output type of the python variable; valid types are [int, float, str]
+        :param outtype: [optional] desired output type of the python variable; valid types are [int, float, str] \
+                        provide an object of the type [1, 1.0, ' '] or a string of 'int', 'float' or 'str' 
 
         """
         ll = self._io.submit("%put " + name + "=&" + name + " "+ name+"END=;\n")
         l2 = ll['LOG'].rpartition(name + "=")[2].rpartition(name+"END=")[0].strip().replace('\n','') 
 
+        if outtype is not None:
+           if   outtype == 'int':
+              outtype = 1
+           elif outtype == 'float':
+              outtype = 1.0
+
         if outtype is not None and type(outtype) not in [int, float, str]:
            print("invalid type specified. supported are [int, float, str], will return default type")
            outtype=None
@@ -1569,6 +1582,19 @@ class SASsession():
 
         return var
 
+    def symexist(self, name: str):
+        """
+        :param name:    [required] name of the macro varable to check for existence
+
+        :return: bool
+        """
+        ll = self._io.submit("%put " + name + "=%symexist(" + name + ") "+ name+"END=;\n")
+        l2 = ll['LOG'].rpartition(name + "=")[2].rpartition(name+"END=")[0].strip().replace('\n','') 
+
+        var = int(l2)
+
+        return bool(var)
+
     def disconnect(self):
         """
         This method disconnects an IOM session to allow for reconnecting when switching networks
