@@ -247,7 +247,7 @@ class SASdata:
 
         le = self._is_valid()
         if not le:
-            ll = self.sas.submit(code, "text")
+            ll = self.sas._io.submit(code, "text")
 
             lastobs = ll['LOG'].rpartition("lastobs=")
             lastobs = lastobs[2].partition(" lastobsend=")
@@ -318,7 +318,7 @@ class SASdata:
 
         le = self._is_valid()
         if not le:
-            ll = self.sas.submit(code, "text")
+            ll = self.sas._io.submit(code, "text")
 
             lastobs = ll['LOG'].rpartition("lastobs=")
             lastobs = lastobs[2].partition(" lastobsend=")
@@ -402,7 +402,7 @@ class SASdata:
                     # ignore teach_me_SAS mode to run contents
                     nosub = self.sas.nosub
                     self.sas.nosub = False
-                    ll = self.sas.submit(num_string.format(self.libref, self.table + self._dsopts()))
+                    ll = self.sas._io.submit(num_string.format(self.libref, self.table + self._dsopts()))
                     self.sas.nosub = nosub
 
                     numlist = []
@@ -453,7 +453,7 @@ class SASdata:
         if ll:
             runcode = False
         if runcode:
-            ll = self.sas.submit(code + split_code, "text")
+            ll = self.sas._io.submit(code + split_code, "text")
             elog = []
             for line in ll['LOG'].splitlines():
                 if line[self.sas.logoffset:].startswith('ERROR'):
@@ -768,7 +768,7 @@ class SASdata:
         if self.sas.nosub:
             print(modesql + sql + ds1)
             return None
-        ll = self.sas.submit(modesql + sql + ds1)
+        ll = self.sas._io.submit(modesql + sql + ds1)
         return self.sas.sasdata(out_table, libref=out_libref, results=self.results, dsopts=self._dsopts())
 
     def sort(self, by: str, out: object = '', **kwargs) -> 'SASdata':
@@ -824,7 +824,7 @@ class SASdata:
         if ll:
             runcode = False
         if runcode:
-            ll = self.sas.submit(code, "text")
+            ll = self.sas._io.submit(code, "text")
             elog = []
             for line in ll['LOG'].splitlines():
                 if line[self.sas.logoffset:].startswith('ERROR'):
@@ -899,7 +899,7 @@ class SASdata:
         :return: SAS result object
         """
         # submit autocall macro
-        self.sas.submit("%aamodel;")
+        self.sas._io.submit("%aamodel;")
         objtype = "datastep"
         objname = '{s:{c}^{n}}'.format(s=self.table[:3], n=3,
                                        c='_') + self.sas._objcnt()  # translate to a libname so needs to be less than 8
@@ -992,7 +992,7 @@ class SASdata:
             print(code)
             return
 
-        ll = self.sas.submit(code, 'text')
+        ll = self.sas._io.submit(code, 'text')
         obj1 = sp2.SASProcCommons._objectmethods(self, objname)
         return sp2.SASresults(obj1, self.sas, objname, self.sas.nosub, ll['LOG'])
 
@@ -1174,7 +1174,7 @@ class SASdata:
         if ll:
             runcode = False
         if runcode:
-            ll = self.sas.submit(code, "text")
+            ll = self.sas._io.submit(code, "text")
             elog = []
             fpath=''
             for line in ll['LOG'].splitlines():
@@ -1513,3 +1513,96 @@ class SASdata:
        else:
           return failmsg+ll['LOG']
 
+    def delete(self, quiet=False):
+       """
+       Delete this data set; the SASdata object is still available
+
+       :return: SASLOG for this step
+       """
+       code  = "proc delete data="+self.libref + ".'" + self.table + "'n;run;" 
+
+       if self.sas.nosub:
+          print(code)
+          return
+
+       ll = self.sas._io.submit(code, results='text')
+
+       if self.sas.exist(self.table, self.libref):
+          ll['LOG'] = "Data set still exists. Delete must have failed.\n"+ll['LOG']
+
+       if not self.sas.batch:
+          if not quiet:
+             print(ll['LOG'])
+          return None
+       else:
+          return ll['LOG']
+
+    def append(self, data, force: bool=False):
+       """
+       Append 'data' to this SAS Data Set. data can either be another SASdataobject or
+       a Pandas DataFrame, in which case dataframe2sasdata(data) will be run for you to
+       load the data into a SAS data Set which will then be appended to this data set.
+
+       :param data: Either a SASdata object or a Pandas DataFrame
+       :param force: boolean to force appended even if anomolies exist which could cause dropping or truncating 
+       :return: SASLOG for this step
+       """
+       new = None
+
+       if not self.sas.sascfg.pandas:
+          if type(data) is pandas.core.frame.DataFrame:
+             new = 'df'
+       else:
+          new = 'no pandas'
+
+       if type(data) is type(self):
+          new = 'sd'
+
+       if new not in ['df','sd']:
+          failmsg = "The data parameter passed in must be either a SASdata object or a Pandas DataFrame. No data was appended."
+          if not self.sas.batch:
+             print(failmsg)
+             return None
+          else:
+             return failmsg
+
+       if new == 'df':
+          new = self.sas.df2sd(data, '_temp_df')
+          if type(new) is not type(self):
+             failmsg = "df2sd on input data failed. Check SASLOG for errors."
+             if not self.sas.batch:
+                print(failmsg)
+                return None
+             else:
+                return failmsg
+       else:
+          new = data
+
+       if self.sas.nosub:
+          print(code)
+          return
+
+       if not self.sas.exist(new.table, new.libref):
+          failmsg = "Data set to be appended doesn't exist. No data was appended."
+          if not self.sas.batch:
+             print(failmsg)
+             return None
+          else:
+             return failmsg
+
+       code  = "proc append base="+self.libref+".'"+self.table+"'n\n"
+       code += "            data="+ new.libref+".'"+ new.table+"'n"+new._dsopts()
+       if force: 
+          code += "\n   force" 
+       code += ";\nrun;" 
+
+       ll = self.sas._io.submit(code, results='text')
+
+       new.delete(quiet=True)
+
+       if not self.sas.batch:
+          print(ll['LOG'])
+          return None
+       else:
+          return ll['LOG']
+
