@@ -51,6 +51,7 @@ class SASconfigHTTP:
       self.options   = cfg.get('options', [])
       self.ssl       = cfg.get('ssl', True)
       self.verify    = cfg.get('verify', True)
+      self.timeout   = cfg.get('timeout', None)
       user           = cfg.get('user', '')
       pw             = cfg.get('pw', '')
       self.encoding  = cfg.get('encoding', '')
@@ -122,6 +123,13 @@ class SASconfigHTTP:
          else:
             self.verify = bool(inver)
 
+      intout = kwargs.get('timeout', None)
+      if intout is not None:
+         if lock and self.timeout:
+            print("Parameter 'timeout' passed to SAS_session was ignored due to configuration restriction.")
+         else:
+            self.timeout = intout
+
       inuser = kwargs.get('user', '')              
       if len(inuser) > 0:
          if lock and len(user):
@@ -164,9 +172,12 @@ class SASconfigHTTP:
       while len(self.ip) == 0:
          if not lock:
             self.ip = self._prompt("Please enter the host (ip address) you are trying to connect to: ")
+            if self.ip is None:
+               self._token = None
+               raise RuntimeError("No IP address provided.") 
          else:
             print("In lockdown mode and missing ip adress in the config named: "+cfgname )
-            return
+            raise RuntimeError("No IP address provided.") 
 
       if not self.port:
          if self.ssl:
@@ -202,30 +213,30 @@ class SASconfigHTTP:
          user = self._prompt("Please enter userid: ")
          if user is None:
             self._token = None
-            return 
+            raise RuntimeError("No userid provided.") 
 
       while len(pw) == 0:
          pw = self._prompt("Please enter password: ", pw = True)
          if pw is None:
             self._token = None
-            return 
+            raise RuntimeError("No password provided.") 
 
       if self.ssl:
          if self.verify:
             # handle having self signed certificate default on Viya w/out copies on client; still ssl, just not verifyable
             try:
-               self.HTTPConn = hc.HTTPSConnection(self.ip, self.port)
+               self.HTTPConn = hc.HTTPSConnection(self.ip, self.port, timeout=self.timeout)
                self._token = self._authenticate(user, pw)
             except ssl.SSLError as e:
                print("SSL connection failed, creating an unverified ssl connection. Error was:"+str(e))
-               self.HTTPConn = hc.HTTPSConnection(self.ip, self.port, context=ssl._create_unverified_context())
+               self.HTTPConn = hc.HTTPSConnection(self.ip, self.port, timeout=self.timeout, context=ssl._create_unverified_context())
                print("You can set 'verify=False' to get rid of this message ")
                self._token   = self._authenticate(user, pw)
          else:
-            self.HTTPConn = hc.HTTPSConnection(self.ip, self.port, context=ssl._create_unverified_context())
+            self.HTTPConn = hc.HTTPSConnection(self.ip, self.port, timeout=self.timeout, context=ssl._create_unverified_context())
             self._token = self._authenticate(user, pw)
       else:
-         self.HTTPConn = hc.HTTPConnection(self.ip, self.port)
+         self.HTTPConn = hc.HTTPConnection(self.ip, self.port, timeout=self.timeout)
          self._token   = self._authenticate(user, pw)
 
       # get AuthToken
@@ -239,47 +250,64 @@ class SASconfigHTTP:
       contexts = self._get_contexts()
       if contexts == None:
          self._token = None
-         return 
+         raise SASHTTPconnectionError(msg="No Contexts found on Compute Service at ip="+self.ip)
 
       ctxnames = []
       for i in range(len(contexts)):
          ctxnames.append(contexts[i].get('name'))
 
+      if len(ctxnames) == 0:
+         self._token = None
+         raise SASHTTPconnectionError(msg="No Contexts found on Compute Service at ip="+self.ip)
+
       if len(self.ctxname) == 0:
-         if len(ctxnames) == 0:
-            print("No Contexts found on Compute Service at ip=" + self.ip)
-            self._token = None
-            return 
+         if len(ctxnames) == 1:
+            self.ctxname = ctxnames[0]
+            print("Using SAS Context: " + self.ctxname)
          else:
-            if len(ctxnames) == 1:
-               self.ctxname = ctxnames[0]
-               print("Using SAS Context: " + self.ctxname)
-            else:
-               self.ctxname = self._prompt("Please enter the SAS Context you wish to run. Available contexts are: " +
-                                            str(ctxnames)+" ")
-               if self.ctxname is None:
+            try:
+               ctxname = self._prompt("Please enter the SAS Context you wish to run. Available contexts are: " +
+                                      str(ctxnames)+" ")
+               if ctxname is None:
                   self._token = None
-                  return 
+                  raise RuntimeError("No SAS Context provided.") 
+               else:
+                  self.ctxname = ctxname
+            except:
+               raise SASHTTPconnectionError(msg=
+                  "SAS Context specified '"+self.ctxname+"' was not found. Prompting failed. Available contexts were: " + 
+                   str(ctxnames)+" ")
 
       while self.ctxname not in ctxnames:
          if not lock:
+            '''    this was original code before compute was production. users can't create these on the fly.
             createctx = self._prompt(
                 "SAS Context specified was not found. Do you want to create a new context named "+self.ctxname+" [Yes|No]?")
             if createctx.upper() in ('YES', 'Y'):
                contexts = self._create_context(user)
             else:
-               self.ctxname = self._prompt(
+            '''
+            try:
+               ctxname = self._prompt(
                    "SAS Context specified was not found. Please enter the SAS Context you wish to run. Available contexts are: " + 
                     str(ctxnames)+" ")
-               if self.ctxname is None:
+               if ctxname is None:
                   self._token = None
-                  return 
+                  raise SASHTTPconnectionError(msg=
+                      "SAS Context specified '"+self.ctxname+"' was not found. Prompting failed. Available contexts were: " + 
+                       str(ctxnames)+" ")
+               else:
+                  self.ctxname = ctxname
+            except:
+               raise SASHTTPconnectionError(msg=
+                   "SAS Context specified '"+self.ctxname+"' was not found. Prompting failed. Available contexts were: " + 
+                    str(ctxnames)+" ")
          else:
             msg  = "SAS Context specified in the SASconfig ("+self.ctxname+") was not found on this server, and because " 
             msg += "the SASconfig is in lockdown mode, there is no prompting for other contexts. No connection established."
             print(msg)
             self._token = None
-            return 
+            raise RuntimeError("No SAS Context provided.") 
 
       for i in range(len(contexts)):
          if contexts[i].get('name') == self.ctxname:
@@ -720,6 +748,8 @@ class SASsessionHTTP():
             gotit = False
             while not gotit:
                var = self.sascfg._prompt('Please enter value for macro variable '+key+' ', pw=prompt[key])
+               if var is None:
+                  raise RuntimeError("No value for prompted macro variable provided.") 
                if len(var) > 0:
                   gotit = True
                else:
@@ -775,7 +805,7 @@ class SASsessionHTTP():
             response = self.sascfg._prompt(
                       "SAS attention handling not yet supported over HTTP. Please enter (Q) to Quit waiting for results or (C) to continue waiting.")
             while True:
-               if response.upper() == 'Q':
+               if response is None or response.upper() == 'Q':
                   conn.close()
                   return dict(LOG='', LST='', BC=True)
                if response.upper() == 'C':
